//[mahjong-utils](index.md)

# mahjong-utils

## Packages

| Name |
|---|
| [mahjongutils.hanhu](mahjong-utils/mahjongutils.hanhu/index.md) |
| [mahjongutils.hora](mahjong-utils/mahjongutils.hora/index.md) |
| [mahjongutils.models](mahjong-utils/mahjongutils.models/index.md) |
| [mahjongutils.models.hand](mahjong-utils/mahjongutils.models.hand/index.md) |
| [mahjongutils.shanten](mahjong-utils/mahjongutils.shanten/index.md) |
| [mahjongutils.yaku](mahjong-utils/mahjongutils.yaku/index.md) |
